/*
 * pdsdatafunc.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file pdsdatafunc.h
 *  \brief Archivo de definición de módulos de la biblioteca PDS Data Functions.
 *
 *  Aquí podras habilitar o deshabilitar los módulos que quieras.
 *  \author Fernando Pujaico Rivera
 */
#ifndef __PDSDATAFUNC_H__
#define __PDSDATAFUNC_H__


#include <pds/pdsargsfunc.h>
#include <pds/pdsstring.h>
#include <pds/pdsfilesfunc.h>
#include <pds/pdslstring.h>
#include <pds/pdscstring.h>


#endif /* __PDSDATAFUNC_H__ */
